@@ -19,10 +19,7 @@ from pytorchvideo.data.dataset_manifest_utils import (
     VideoDataset,
     VideoDatasetType,
 )
-from pytorchvideo.data.utils import (
-    DataclassFieldCaster,
-    load_dataclass_dict_from_csv,
-)
+from pytorchvideo.data.utils import DataclassFieldCaster, load_dataclass_dict_from_csv
 from pytorchvideo.data.video import Video
 
 
