@@ -7,7 +7,7 @@ import torch
 import torch.nn as nn
 from pytorchvideo.layers.utils import set_attributes
 from pytorchvideo.models.head import create_res_basic_head, create_res_roi_pooling_head
-from pytorchvideo.models.net import Net, DetectionBBoxNetwork
+from pytorchvideo.models.net import DetectionBBoxNetwork, Net
 from pytorchvideo.models.stem import (
     create_acoustic_res_basic_stem,
     create_res_basic_stem,
@@ -316,6 +316,13 @@ def create_acoustic_bottleneck_block(
     )
 
 
+def _trivial_sum(x, y):
+    """
+    Utility function used in lieu of lamda which are not picklable
+    """
+    return x + y
+
+
 def create_res_block(
     *,
     # Bottleneck Block configs.
@@ -324,7 +331,7 @@ def create_res_block(
     dim_out: int,
     bottleneck: Callable,
     use_shortcut: bool = False,
-    branch_fusion: Callable = lambda x, y: x + y,
+    branch_fusion: Callable = _trivial_sum,
     # Conv configs.
     conv_a_kernel_size: Tuple[int] = (3, 1, 1),
     conv_a_stride: Tuple[int] = (2, 1, 1),
